@@ -42,7 +42,7 @@ DEFAULT_SPECD_PATH = os.path.join(
     os.path.dirname(__file__), "../../gosdk/specs/"
 )
 
-VERSION = "0.9.6"
+VERSION = "0.9.7"
 COPYRIGHT = "Copyright: GenomOncology, LLC"
 
 
@@ -412,8 +412,13 @@ def to_tsv(column, include_header):
 
 
 @gocli.command()
-def to_vcf():
+@click.option(
+    "--historical", "-h", help="Write annotations to VCF.", is_flag=True
+)
+def to_vcf(historical):
     """Render calls to VCF file format."""
+    if historical:
+        return [sinks.HistoricalVcfFileSink()]
     return [sinks.VcfFileSink()]
 
 
