@@ -26,8 +26,7 @@ def hotspot_annotate(data, data_set, data_set_version, sdk=None):
         sdk.annotations.load_annotations,
         data_set=data_set,
         data_set_version=data_set_version,
-        data=annotated_hotspots
-
+        data=annotated_hotspots,
     )
 
     return annotations_list
@@ -171,13 +170,13 @@ def convert_to_csra(data):
 
 
 def get_mutation_type(record):
-    if "*" in record['Residue']:
+    if "*" in record["Residue"]:
         return ["Nonstop Extension"]
-    elif "X" in record['Residue']:
+    elif "X" in record["Residue"]:
         return ["Splice Donor Site", "Splice Acceptor Site"]
-    elif "*" in record['Variants'] and "|" in record['Variants']:
+    elif "*" in record["Variants"] and "|" in record["Variants"]:
         return ["Substitution - Missense", "Substitution - Nonsense"]
-    elif "*" in record['Variants']:
+    elif "*" in record["Variants"]:
         return ["Substitution - Nonsense"]
     else:
         return ["Substitution - Missense"]
@@ -186,33 +185,33 @@ def get_mutation_type(record):
 def annotate_hotspots(data):
     print(data)
     annotations = []
-    num_pattern = re.compile('[0-9]+')
-    alpha_pattern = re.compile('[a-zA-Z]+')
+    num_pattern = re.compile("[0-9]+")
+    alpha_pattern = re.compile("[a-zA-Z]+")
     for record in data:
         ann = {}
-        ann['gene'] = record['Gene']
-        ann['is_hotspot_annotation'] = True
-        if record['Type'] == 'single residue':
-            ref_aa = num_pattern.sub('', record['Residue'])
-            pos = alpha_pattern.sub('', record['Residue'])
-            if ref_aa != 'X':
-                ann['codon_start'] = pos
-                ann['codon_end'] = pos
-                ann['ref_aa_start'] = ref_aa
-                ann['ref_aa_end'] = ref_aa
+        ann["gene"] = record["Gene"]
+        ann["is_hotspot_annotation"] = True
+        if record["Type"] == "single residue":
+            ref_aa = num_pattern.sub("", record["Residue"])
+            pos = alpha_pattern.sub("", record["Residue"])
+            if ref_aa != "X":
+                ann["codon_start"] = pos
+                ann["codon_end"] = pos
+                ann["ref_aa_start"] = ref_aa
+                ann["ref_aa_end"] = ref_aa
             else:
-                ann['nearest_codon'] = pos
-            ann['hotspot_mutation_type'] = get_mutation_type(record)
-        elif record['Type'] == 'in-frame indel':
-            start_end = record['Residue'].split("-")
-            ann['codon_start'] = start_end[0]
-            ann['codon_end'] = start_end[1]
-            ann['hotspot_mutation_type'] = [
+                ann["nearest_codon"] = pos
+            ann["hotspot_mutation_type"] = get_mutation_type(record)
+        elif record["Type"] == "in-frame indel":
+            start_end = record["Residue"].split("-")
+            ann["codon_start"] = start_end[0]
+            ann["codon_end"] = start_end[1]
+            ann["hotspot_mutation_type"] = [
                 "Insertion - In frame",
                 "Deletion - In frame",
                 "Complex - insertion inframe",
                 "Complex - deletion inframe",
-                "Complex - compound substitution"
+                "Complex - compound substitution",
             ]
 
         annotations.append(ann)
