@@ -3,8 +3,9 @@ from .bed import BedFileSource
 from .delimited import DelimitedFileSource
 from .paths import CollectFilePathsSource
 from .excel import ExcelSource
-from .aggregated import AggregatedFileSource
+from .aggregated import AggregatedCOSMICSources, AggregatedFileSource
 from .maf import MAFSource
+from .xml import XMLSource
 from . import one_off_sources
 
 __all__ = (
@@ -16,8 +17,10 @@ __all__ = (
     "DelimitedFileSource",
     "CollectFilePathsSource",
     "ExcelSource",
+    "AggregatedCOSMICSources",
     "AggregatedFileSource",
     "MAFSource",
+    "XMLSource",
 )
 
 
