@@ -230,9 +230,7 @@ class ClinvarXMLSource:
                         sl.attrib.get("referenceAlleleVCF"),
                         sl.attrib.get("alternateAlleleVCF"),
                     )
-                    if ref == alt or not all(
-                        [chr, pos, ref, alt]
-                    ):
+                    if ref == alt or not all([chr, pos, ref, alt]):
                         return None
                     else:
                         return f"chr{chr}|{pos}|{ref}|{alt}|GRCh37"
