@@ -19,7 +19,7 @@ NAME_MAPPING = {
     "ID__mstring": "ID",
     "CDS__mstring": "CDS",
     "AA__mstring": "AA",
-    "legacy_id__mstring": "LEGACY_ID"
+    "legacy_id__mstring": "LEGACY_ID",
 }
 
 
@@ -51,9 +51,9 @@ def dict_list_to_key_value_list(x, field):
 
 def clean_gene(x):
     # remove dups and remove everything after "_ENST"
-    return list(set([
-        gene.split("_ENST")[0] for gene in x if gene is not None
-    ]))
+    return list(
+        set([gene.split("_ENST")[0] for gene in x if gene is not None])
+    )
 
 
 def remove_start_field(x):
